summaryrefslogtreecommitdiffstats
path: root/kmahjongg
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
commit84ace1135cac57993b72fee7105b92def1638d32 (patch)
treeb8871eb76e3db4a062731b0ce7c99c24fac119e8 /kmahjongg
parent97d1732e257f8700488d7ca1660ae7eba8fc6065 (diff)
downloadtdegames-84ace1135cac57993b72fee7105b92def1638d32.tar.gz
tdegames-84ace1135cac57993b72fee7105b92def1638d32.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 97d1732e257f8700488d7ca1660ae7eba8fc6065.
Diffstat (limited to 'kmahjongg')
-rw-r--r--kmahjongg/BoardLayout.cpp4
-rw-r--r--kmahjongg/BoardLayout.h2
-rw-r--r--kmahjongg/Editor.cpp42
-rw-r--r--kmahjongg/HighScore.cpp14
-rw-r--r--kmahjongg/HighScore.h2
-rw-r--r--kmahjongg/Preview.cpp54
-rw-r--r--kmahjongg/Preview.h2
-rw-r--r--kmahjongg/boardwidget.cpp26
-rw-r--r--kmahjongg/boardwidget.h2
-rw-r--r--kmahjongg/kmahjongg.cpp16
-rw-r--r--kmahjongg/pics/cross.layout2
-rw-r--r--kmahjongg/pics/default.layout2
-rw-r--r--kmahjongg/pics/default.theme2
-rw-r--r--kmahjongg/pics/pirates.layout2
-rw-r--r--kmahjongg/pics/pirates.theme2
-rw-r--r--kmahjongg/pics/pyramid.layout2
-rw-r--r--kmahjongg/pics/stax.layout2
-rw-r--r--kmahjongg/pics/test.layout2
-rw-r--r--kmahjongg/pics/test2.layout2
-rw-r--r--kmahjongg/pics/tower.layout2
-rw-r--r--kmahjongg/pics/triangle.layout2
-rw-r--r--kmahjongg/settings.ui2
22 files changed, 94 insertions, 94 deletions
diff --git a/kmahjongg/BoardLayout.cpp b/kmahjongg/BoardLayout.cpp
index 6b5671a2..8da404ae 100644
--- a/kmahjongg/BoardLayout.cpp
+++ b/kmahjongg/BoardLayout.cpp
@@ -1,8 +1,8 @@
#include "BoardLayout.h"
#include <tqfile.h>
-#include <textstream.h>
-#include <textcodec.h>
+#include <tqtextstream.h>
+#include <tqtextcodec.h>
diff --git a/kmahjongg/BoardLayout.h b/kmahjongg/BoardLayout.h
index 468bf5bc..a9a809c7 100644
--- a/kmahjongg/BoardLayout.h
+++ b/kmahjongg/BoardLayout.h
@@ -4,7 +4,7 @@
#include <tqstring.h>
#include "KmTypes.h"
-const TQString layoutMagic1_0 = "kmahjongg-layout-v1.0";
+const TQString layoutMagic1_0 = "kmahjongg-tqlayout-v1.0";
class BoardLayout {
diff --git a/kmahjongg/HighScore.cpp b/kmahjongg/HighScore.cpp
index 637fdf25..c38e53b1 100644
--- a/kmahjongg/HighScore.cpp
+++ b/kmahjongg/HighScore.cpp
@@ -62,7 +62,7 @@ HighScore::HighScore
qtarch_Label_3->setGeometry( 10, 45, 30, 30 );
qtarch_Label_3->setFrameStyle( 50 );
qtarch_Label_3->setText( i18n("Pos") );
- qtarch_Label_3->setAlignment( AlignCenter );
+ qtarch_Label_3->tqsetAlignment( AlignCenter );
fnt = qtarch_Label_3->font();
fnt.setBold(true);
qtarch_Label_3->setFont(fnt);
@@ -341,7 +341,7 @@ void HighScore::addRow(int num) {
numbersWidgets[num] = new TQLabel( this);
numbersWidgets[num]->setGeometry( 10, 75+(num*30), 30, 30 );
numbersWidgets[num]->setFrameStyle( 50 );
- numbersWidgets[num]->setAlignment( AlignRight | AlignVCenter );
+ numbersWidgets[num]->tqsetAlignment( AlignRight | AlignVCenter );
numbersWidgets[num]->setNum(num+1);
@@ -349,13 +349,13 @@ void HighScore::addRow(int num) {
namesWidgets[num] = new TQLabel( this);
namesWidgets[num]->setGeometry( 40, 75+(num*30), 150, 30 );
namesWidgets[num]->setFrameStyle( 50 );
- namesWidgets[num]->setAlignment( 289 );
+ namesWidgets[num]->tqsetAlignment( 289 );
// board
boardWidgets[num] = new TQLabel( this);
boardWidgets[num]->setGeometry( 190, 75+(num*30), 80, 30 );
boardWidgets[num]->setFrameStyle( 50 );
- boardWidgets[num]->setAlignment( 289 );
+ boardWidgets[num]->tqsetAlignment( 289 );
// score
scoresWidgets[num] = new TQLabel( this);
@@ -396,11 +396,11 @@ void HighScore::copyTableToScreen(const TQString &name) {
elapsedWidgets[p]->setText(buff);
}
- repaint(false);
+ tqrepaint(false);
}
-int HighScore::exec(TQString &layout) {
- copyTableToScreen(layout);
+int HighScore::exec(TQString &tqlayout) {
+ copyTableToScreen(tqlayout);
return(TQDialog::exec());
}
diff --git a/kmahjongg/HighScore.h b/kmahjongg/HighScore.h
index d5513508..a154b3e1 100644
--- a/kmahjongg/HighScore.h
+++ b/kmahjongg/HighScore.h
@@ -41,7 +41,7 @@ public:
virtual ~HighScore();
- int exec(TQString &layout);
+ int exec(TQString &tqlayout);
void checkHighScore(int score, int elapsed, long game, TQString &board);
diff --git a/kmahjongg/Preview.h b/kmahjongg/Preview.h
index f77aaf09..2b0adb54 100644
--- a/kmahjongg/Preview.h
+++ b/kmahjongg/Preview.h
@@ -63,7 +63,7 @@ protected:
virtual void drawPreview();
void applyChange() ;
void renderBackground(const TQString &bg);
- void renderTiles(const TQString &file, const TQString &layout);
+ void renderTiles(const TQString &file, const TQString &tqlayout);
void paintEvent( TQPaintEvent* pa );
signals:
diff --git a/kmahjongg/boardwidget.h b/kmahjongg/boardwidget.h
index 62907097..bee14b49 100644
--- a/kmahjongg/boardwidget.h
+++ b/kmahjongg/boardwidget.h
@@ -205,7 +205,7 @@ class BoardWidget : public TQWidget
- bool updateBackBuffer; // does board need redrawing. Not if it is just a repaint
+ bool updateBackBuffer; // does board need redrawing. Not if it is just a tqrepaint
bool gamePaused;
diff --git a/kmahjongg/kmahjongg.cpp b/kmahjongg/kmahjongg.cpp
index e065b848..8bd9b107 100644
--- a/kmahjongg/kmahjongg.cpp
+++ b/kmahjongg/kmahjongg.cpp
@@ -151,7 +151,7 @@ void KMahjongg::setupKAction()
pauseAction = KStdGameAction::pause(TQT_TQOBJECT(this), TQT_SLOT(pause()), actionCollection());
// TODO: store the background ; open on startup
- // TODO: same about layout
+ // TODO: same about tqlayout
// TODO: same about theme
// move
@@ -179,19 +179,19 @@ void KMahjongg::setupStatusBar()
tilesLeftLabel= new TQLabel("Removed: 0000/0000", statusBar());
tilesLeftLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- statusBar()->addWidget(tilesLeftLabel, tilesLeftLabel->sizeHint().width(), ID_STATUS_GAME);
+ statusBar()->addWidget(tilesLeftLabel, tilesLeftLabel->tqsizeHint().width(), ID_STATUS_GAME);
gameNumLabel = new TQLabel("Game: 000000000000000000000", statusBar());
gameNumLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- statusBar()->addWidget(gameNumLabel, gameNumLabel->sizeHint().width(), ID_STATUS_TILENUMBER);
+ statusBar()->addWidget(gameNumLabel, gameNumLabel->tqsizeHint().width(), ID_STATUS_TILENUMBER);
statusLabel= new TQLabel("Kmahjongg", statusBar());
statusLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- statusBar()->addWidget(statusLabel, statusLabel->sizeHint().width(), ID_STATUS_MESSAGE);
+ statusBar()->addWidget(statusLabel, statusLabel->tqsizeHint().width(), ID_STATUS_MESSAGE);
- // pStatusBar->setAlignment( ID_STATUS_TILENUMBER, AlignCenter );
+ // pStatusBar->tqsetAlignment( ID_STATUS_TILENUMBER, AlignCenter );
}
void KMahjongg::setDisplayedWidth()
@@ -397,7 +397,7 @@ void KMahjongg::gameOver(
void KMahjongg::showStatusText( const TQString &msg, long board )
{
statusLabel->setText(msg);
- TQString str = i18n("Game number: %1").arg(board);
+ TQString str = i18n("Game number: %1").tqarg(board);
gameNumLabel->setText(str);
}
@@ -406,8 +406,8 @@ void KMahjongg::showStatusText( const TQString &msg, long board )
void KMahjongg::showTileNumber( int iMaximum, int iCurrent, int iLeft )
{
// Hmm... seems iCurrent is the number of remaining tiles, not removed ...
- //TQString szBuffer = i18n("Removed: %1/%2").arg(iCurrent).arg(iMaximum);
- TQString szBuffer = i18n("Removed: %1/%2 Combinations left: %3").arg(iMaximum-iCurrent).arg(iMaximum).arg(iLeft);
+ //TQString szBuffer = i18n("Removed: %1/%2").tqarg(iCurrent).tqarg(iMaximum);
+ TQString szBuffer = i18n("Removed: %1/%2 Combinations left: %3").tqarg(iMaximum-iCurrent).tqarg(iMaximum).tqarg(iLeft);
tilesLeftLabel->setText(szBuffer);
// Update here since undo allow is effected by demo mode
diff --git a/kmahjongg/pics/cross.layout b/kmahjongg/pics/cross.layout
index 39c58f1e..de71a115 100644
--- a/kmahjongg/pics/cross.layout
+++ b/kmahjongg/pics/cross.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
12....12121212121212121212....12
4312..43434343434343434343..1243
124312........1212........124312
diff --git a/kmahjongg/pics/default.layout b/kmahjongg/pics/default.layout
index f72ed794..005254ed 100644
--- a/kmahjongg/pics/default.layout
+++ b/kmahjongg/pics/default.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
# Level 0 -------------------------
...121212121212121212121212.....
...434343434343434343434343.....
diff --git a/kmahjongg/pics/default.theme b/kmahjongg/pics/default.theme
index 9ba994bc..49502e04 100644
--- a/kmahjongg/pics/default.theme
+++ b/kmahjongg/pics/default.theme
@@ -1,4 +1,4 @@
kmahjongg-theme-v1.0
:default.tileset
:default.bgnd
-:default.layout
+:default.tqlayout
diff --git a/kmahjongg/pics/pirates.layout b/kmahjongg/pics/pirates.layout
index c5bb895c..3cce44e3 100644
--- a/kmahjongg/pics/pirates.layout
+++ b/kmahjongg/pics/pirates.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
.............121212.......12..12
.............434343.......43..43
.............12.............12..
diff --git a/kmahjongg/pics/pirates.theme b/kmahjongg/pics/pirates.theme
index 748b3ffa..51b6ec88 100644
--- a/kmahjongg/pics/pirates.theme
+++ b/kmahjongg/pics/pirates.theme
@@ -1,5 +1,5 @@
kmahjongg-theme-v1.0
:pirates.tileset
:pirates.bgnd
-:pirates.layout
+:pirates.tqlayout
diff --git a/kmahjongg/pics/pyramid.layout b/kmahjongg/pics/pyramid.layout
index edd634dc..0239212b 100644
--- a/kmahjongg/pics/pyramid.layout
+++ b/kmahjongg/pics/pyramid.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
# Level 0 -------------------------
....121212121212121212121212....
....434343434343434343434343....
diff --git a/kmahjongg/pics/stax.layout b/kmahjongg/pics/stax.layout
index f5595dca..abc7e969 100644
--- a/kmahjongg/pics/stax.layout
+++ b/kmahjongg/pics/stax.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
................................
12121212..121212121212..12121212
43434343..434343434343..43434343
diff --git a/kmahjongg/pics/test.layout b/kmahjongg/pics/test.layout
index d46a4e21..2c76ddec 100644
--- a/kmahjongg/pics/test.layout
+++ b/kmahjongg/pics/test.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
.1212121212121212121212121212...
.4343434343434343434343434343...
.1212121212121212121212121212...
diff --git a/kmahjongg/pics/test2.layout b/kmahjongg/pics/test2.layout
index aedc6290..9ab29fdf 100644
--- a/kmahjongg/pics/test2.layout
+++ b/kmahjongg/pics/test2.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
................................
................................
.121212121212121212.............
diff --git a/kmahjongg/pics/tower.layout b/kmahjongg/pics/tower.layout
index 76fe96a0..3ca7bfc6 100644
--- a/kmahjongg/pics/tower.layout
+++ b/kmahjongg/pics/tower.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
# Level 0 -------------------------
....121212121212121212121212....
....434343434343434343434343....
diff --git a/kmahjongg/pics/triangle.layout b/kmahjongg/pics/triangle.layout
index e1dd4891..e04c405a 100644
--- a/kmahjongg/pics/triangle.layout
+++ b/kmahjongg/pics/triangle.layout
@@ -1,4 +1,4 @@
-kmahjongg-layout-v1.0
+kmahjongg-tqlayout-v1.0
# Level 0 -------------------------
.121212121212121212121212121212.
.434343434343434343434343434343.
diff --git a/kmahjongg/settings.ui b/kmahjongg/settings.ui
index 0cfb2594..594cf9b7 100644
--- a/kmahjongg/settings.ui
+++ b/kmahjongg/settings.ui
@@ -92,7 +92,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/kmahjongg/Editor.cpp b/kmahjongg/Editor.cpp
index 323ccb24..cc80831c 100644
--- a/kmahjongg/Editor.cpp
+++ b/kmahjongg/Editor.cpp
@@ -1,7 +1,7 @@
#include <stdlib.h>
#include <kapplication.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpainter.h>
#include "Editor.h"
@@ -35,7 +35,7 @@
// When we assign a tile to draw in a slot we do it in order from te following
// table, wrapping on the tile number. It makes the tile layout look more
// random.
@@ -69,10 +69,10 @@ Editor::Editor
// setup the tool bar
setupToolbar();
- TQVBoxLayout *layout = new TQVBoxLayout(this, 1);
- layout->addWidget(topToolbar,0);
- layout->addWidget(drawFrame,1);
- layout->activate();
+ TQVBoxLayout *tqlayout = new TQVBoxLayout(this, 1);
+ tqlayout->addWidget(topToolbar,0);
+ tqlayout->addWidget(drawFrame,1);
+ tqlayout->activate();
resize( sWidth+60, sHeight+60);
setMinimumSize( sWidth+60, sHeight+60);
@@ -170,7 +170,7 @@ void Editor::setupToolbar()
// status in the toolbar for now (ick)
theLabel = new TQLabel(statusText(), topToolbar);
- int lWidth = theLabel->sizeHint().width();
+ int lWidth = theLabel->tqsizeHint().width();
topToolbar->insertWidget(ID_TOOL_STATUS,lWidth, theLabel );
topToolbar->alignItemRight( ID_TOOL_STATUS, true );
@@ -209,19 +209,19 @@ void Editor::topToolbarOption(int option) {
break;
case ID_TOOL_LEFT:
theBoard.shiftLeft();
- repaint(false);
+ tqrepaint(false);
break;
case ID_TOOL_RIGHT:
theBoard.shiftRight();
- repaint(false);
+ tqrepaint(false);
break;
case ID_TOOL_UP:
theBoard.shiftUp();
- repaint(false);
+ tqrepaint(false);
break;
case ID_TOOL_DOWN:
theBoard.shiftDown();
- repaint(false);
+ tqrepaint(false);
break;
case ID_TOOL_DEL:
mode=remove;
@@ -260,7 +260,7 @@ TQString Editor::statusText() {
if (x >=BoardLayout::width || x <0 || y >=BoardLayout::height || y <0)
x = y = z = 0;
- buf = i18n("Tiles: %1 Pos: %2,%3,%4").arg(numTiles).arg(x).arg(y).arg(z);
+ buf = i18n("Tiles: %1 Pos: %2,%3,%4").tqarg(numTiles).tqarg(x).tqarg(y).tqarg(z);
return buf;
}
@@ -272,7 +272,7 @@ void Editor::loadBoard() {
KURL url = KFileDialog::getOpenURL(
NULL,
- i18n("*.layout|Board Layout (*.layout)\n"
+ i18n("*.tqlayout|Board Layout (*.tqlayout)\n"
"*|All Files"),
this,
i18n("Open Board Layout" ));
@@ -283,7 +283,7 @@ void Editor::loadBoard() {
theBoard.loadBoardLayout( url.path() );
- repaint(false);
+ tqrepaint(false);
}
@@ -302,14 +302,14 @@ void Editor::newBoard() {
clean=true;
numTiles=0;
statusChanged();
- repaint(false);
+ tqrepaint(false);
}
bool Editor::saveBoard() {
// get a save file name
KURL url = KFileDialog::getSaveURL(
NULL,
- i18n("*.layout|Board Layout (*.layout)\n"
+ i18n("*.tqlayout|Board Layout (*.tqlayout)\n"
"*|All Files"),
this,
i18n("Save Board Layout" ));
@@ -373,7 +373,7 @@ bool Editor::testSave()
// The main paint event, draw in the grid and blit in
// the tiles as specified by the layout.
void Editor::paintEvent( TQPaintEvent* ) {
@@ -386,7 +386,7 @@ void Editor::paintEvent( TQPaintEvent* ) {
drawTiles(&buff);
bitBlt(dest, 0,0,&buff, 0,0,buff.width(), buff.height(), CopyROP);
- drawFrame->repaint(false);
+ drawFrame->tqrepaint(false);
}
void Editor::drawBackground(TQPixmap *pixmap) {
@@ -564,7 +564,7 @@ void Editor::drawFrameMousePressEvent( TQMouseEvent* e )
numTiles--;
statusChanged();
drawFrameMouseMovedEvent(e);
- repaint(false);
+ tqrepaint(false);
}
break;
case insert: {
@@ -577,7 +577,7 @@ void Editor::drawFrameMousePressEvent( TQMouseEvent* e )
theBoard.insertTile(n);
numTiles++;
statusChanged();
- repaint(false);
+ tqrepaint(false);
}
}
break;
@@ -599,7 +599,7 @@ void Editor::drawCursor(POSITION &p, bool visible)
if (p.e==100 || !visible)
x = -1;
drawFrame->setRect(x,y,w,h, tiles.shadowSize(), mode-remove);
- drawFrame->repaint(false);
+ drawFrame->tqrepaint(false);
@@ -35,7 +35,7 @@
// When we assign a tile to draw in a slot we do it in order from te following
-// table, wrapping on the tile number. It makes the tile layout look more
+// table, wrapping on the tile number. It makes the tile tqlayout look more
// random.
@@ -373,7 +373,7 @@ bool Editor::testSave()
// The main paint event, draw in the grid and blit in
-// the tiles as specified by the layout.
+// the tiles as specified by the tqlayout.
void Editor::paintEvent( TQPaintEvent* ) {
diff --git a/kmahjongg/Preview.cpp b/kmahjongg/Preview.cpp
index 9c6ac478..ff635e5c 100644
--- a/kmahjongg/Preview.cpp
+++ b/kmahjongg/Preview.cpp
@@ -41,7 +41,7 @@ Preview::Preview(TQWidget* parent) : KDialogBase(parent), m_tiles(true)
m_changed = false;
setMainWidget(page);
- setFixedSize(sizeHint());
+ setFixedSize(tqsizeHint());
}
Preview::~Preview()
@@ -52,7 +52,7 @@ void Preview::selectionChanged(int which)
{
m_selectedFile = m_fileList[which];
drawPreview();
- m_drawFrame->repaint(0,0,-1,-1,false);
+ m_drawFrame->tqrepaint(0,0,-1,-1,false);
markChanged();
}
@@ -76,7 +76,7 @@ void Preview::initialise(const PreviewType type)
TQString extension;
TQString tile = Prefs::tileSet();
TQString back = Prefs::background();
- TQString layout = Prefs::layout();
+ TQString tqlayout = Prefs::layout();
// set up the concept of the current file. Initialised to the preferences
// value initially. Set the caption to indicate what we are doing
@@ -98,10 +98,10 @@ void Preview::initialise(const PreviewType type)
break;
case board:
- m_fileSelector = i18n("*.layout|Board Layout File (*.layout)\n");
+ m_fileSelector = i18n("*.tqlayout|Board Layout File (*.tqlayout)\n");
setCaption(i18n("Change Board Layout"));
- m_selectedFile = layout;
- extension = "*.layout";
+ m_selectedFile = tqlayout;
+ extension = "*.tqlayout";
break;
case theme:
@@ -162,12 +162,12 @@ void Preview::load() {
if ( !url.isEmpty() ) {
m_selectedFile = url.path();
drawPreview();
- m_drawFrame->repaint(0,0,-1,-1,false);
+ m_drawFrame->tqrepaint(0,0,-1,-1,false);
markChanged();
}
}
// Top level preview drawing method. Background, tileset and layout
// are initialised from the preferences. Depending on the type
// of preview dialog we pick up the selected file for one of these
// chaps.
@@ -176,7 +176,7 @@ void Preview::drawPreview()
{
TQString tile = Prefs::tileSet();
TQString back = Prefs::background();
- TQString layout = Prefs::layout();
+ TQString tqlayout = Prefs::layout();
switch (m_previewType)
{
@@ -189,12 +189,12 @@ void Preview::drawPreview()
break;
case board:
- layout = m_selectedFile;
+ tqlayout = m_selectedFile;
break;
case theme:
// a theme is quite a bit of work. We load the
// specified bits in (layout, background and tileset
if (!m_selectedFile.isEmpty())
{
TQString backRaw, layoutRaw, tilesetRaw, magic;
@@ -233,17 +233,17 @@ void Preview::drawPreview()
back = locate("appdata", back);
}
- layout = layoutRaw;
- layout.replace(":", "/kmahjongg/pics/");
- if (!TQFile::exists(layout))
+ tqlayout = layoutRaw;
+ tqlayout.replace(":", "/kmahjongg/pics/");
+ if (!TQFile::exists(tqlayout))
{
- layout = layoutRaw;
- layout = "pics/" + layout.right(layout.length() - layout.find(":") - 1);
- layout = locate("appdata", layout);
+ tqlayout = layoutRaw;
+ tqlayout = "pics/" + tqlayout.right(tqlayout.length() - tqlayout.find(":") - 1);
+ tqlayout = locate("appdata", tqlayout);
}
m_themeBack=back;
- m_themeLayout=layout;
+ m_themeLayout=tqlayout;
m_themeTileset=tile;
}
}
@@ -251,16 +251,16 @@ void Preview::drawPreview()
}
renderBackground(back);
- renderTiles(tile, layout);
+ renderTiles(tile, tqlayout);
}
void Preview::paintEvent( TQPaintEvent* ){
- m_drawFrame->repaint(false);
+ m_drawFrame->tqrepaint(false);
}
// the user selected ok, or apply. This method passes the changes
// across to the game widget and if necessary forces a board redraw
// (unnecessary on layout changes since it only effects the next game)
void Preview::applyChange()
{
switch (m_previewType)
@@ -287,7 +287,7 @@ void Preview::applyChange()
break;
}
// don't redraw for a layout change
if (m_previewType == board || m_previewType == theme) layoutChange();
else boardRedraw(true);
@@ -310,9 +310,9 @@ void Preview::renderBackground(const TQString &bg) {
// This method draws a mini-tiled board with no tiles missing.
-void Preview::renderTiles(const TQString &file, const TQString &layout) {
+void Preview::renderTiles(const TQString &file, const TQString &tqlayout) {
m_tiles.loadTileset(file, true);
- m_boardLayout.loadBoardLayout(layout);
+ m_boardLayout.loadBoardLayout(tqlayout);
TQPixmap *dest = m_drawFrame->getPreviewPixmap();
int xOffset = m_tiles.width()/2;
@@ -366,7 +366,7 @@ void Preview::renderTiles(const TQString &file, const TQString &layout) {
void Preview::saveTheme() {
TQString tile = Prefs::tileSet();
TQString back = Prefs::background();
- TQString layout = Prefs::layout();
+ TQString tqlayout = Prefs::layout();
TQString with = ":";
// we want to replace any path in the default store
@@ -375,7 +375,7 @@ void Preview::saveTheme() {
back.replace(p,with);
tile.replace(p,with);
- layout.replace(p,with);
+ tqlayout.replace(p,with);
// Get the name of the file to save
@@ -417,7 +417,7 @@ void Preview::saveTheme() {
themeMagicV1_0,
tile.utf8().data(),
back.utf8().data(),
- layout.utf8().data());
+ tqlayout.utf8().data());
fclose(outFile);
}
@@ -162,12 +162,12 @@ void Preview::load() {
}
}
-// Top level preview drawing method. Background, tileset and layout
+// Top level preview drawing method. Background, tileset and tqlayout
// are initialised from the preferences. Depending on the type
// of preview dialog we pick up the selected file for one of these
@@ -189,12 +189,12 @@ void Preview::drawPreview()
case theme:
// a theme is quite a bit of work. We load the
- // specified bits in (layout, background and tileset
+ // specified bits in (tqlayout, background and tileset
if (!m_selectedFile.isEmpty())
{
@@ -251,16 +251,16 @@ void Preview::drawPreview()
// the user selected ok, or apply. This method passes the changes
// across to the game widget and if necessary forces a board redraw
-// (unnecessary on layout changes since it only effects the next game)
+// (unnecessary on tqlayout changes since it only effects the next game)
void Preview::applyChange()
{
@@ -287,7 +287,7 @@ void Preview::applyChange()
break;
}
- // don't redraw for a layout change
+ // don't redraw for a tqlayout change
if (m_previewType == board || m_previewType == theme) layoutChange();
else boardRedraw(true);
diff --git a/kmahjongg/boardwidget.cpp b/kmahjongg/boardwidget.cpp
index 23d183ab..aca8c302 100644
--- a/kmahjongg/boardwidget.cpp
+++ b/kmahjongg/boardwidget.cpp
@@ -45,7 +45,7 @@ BoardWidget::BoardWidget( TQWidget* parent, const char *name )
if (!loadTileset(tFile)){
KMessageBox::error(this,
i18n("An error occurred when loading the tileset file %1\n"
- "KMahjongg will now terminate.").arg(tFile));
+ "KMahjongg will now terminate.").tqarg(tFile));
kapp->quit();
}
@@ -55,17 +55,17 @@ BoardWidget::BoardWidget( TQWidget* parent, const char *name )
if( ! loadBackground(tFile, false ) )
{
KMessageBox::error(this,
- i18n("An error occurred when loading the background image\n%1").arg(tFile)+
+ i18n("An error occurred when loading the background image\n%1").tqarg(tFile)+
i18n("KMahjongg will now terminate."));
kapp->quit();
}
- getFileOrDefault(Prefs::layout(), "layout", tFile);
+ getFileOrDefault(Prefs::layout(), "tqlayout", tFile);
if( ! loadBoardLayout(tFile) )
{
KMessageBox::error(this,
- i18n("An error occurred when loading the board layout %1\n"
- "KMahjongg will now terminate.").arg(tFile));
+ i18n("An error occurred when loading the board tqlayout %1\n"
+ "KMahjongg will now terminate.").tqarg(tFile));
kapp->quit();
}
setDisplayedWidth();
@@ -92,7 +92,7 @@ void BoardWidget::saveSettings(){
//config->writePathEntry("Tileset_file", tileFile);
//config->writePathEntry("Background_file", backgroundFile);
- //config->writePathEntry("Layout_file", layout);
+ //config->writePathEntry("Layout_file", tqlayout);
}
void BoardWidget::getFileOrDefault(TQString filename, TQString type, TQString &res)
@@ -111,7 +111,7 @@ void BoardWidget::getFileOrDefault(TQString filename, TQString type, TQString &r
if (res.isEmpty()) {
KMessageBox::error(this, i18n("KMahjongg could not locate the file: %1\n"
"or the default file of type: %2\n"
- "KMahjongg will now terminate").arg(filename).arg(type) );
+ "KMahjongg will now terminate").tqarg(filename).tqarg(type) );
kapp->quit();
}
}
@@ -264,7 +264,7 @@ void BoardWidget::paintEvent( TQPaintEvent* pa )
return;
}
- // if the repaint is because of a window redraw after a move
+ // if the tqrepaint is because of a window redraw after a move
// or a menu roll up, then just blit in the last rendered image
if (!updateBackBuffer) {
bitBlt(this, xx,pa->rect().top(),
@@ -766,7 +766,7 @@ void BoardWidget::calculateNewGame( int gNumber)
}
// ---------------------------------------------------------
// Generate the position data for the layout from contents of Game.Map.
void BoardWidget::generateTilePositions() {
numTiles = 0;
@@ -788,7 +788,7 @@ void BoardWidget::generateTilePositions() {
}
// ---------------------------------------------------------
// Generate the dependency data for the layout from the position data.
// Note that the coordinates of each tile in tilePositions are those of
// the upper left quarter of the tile.
void BoardWidget::generatePositionDepends() {
@@ -1393,7 +1393,7 @@ bool BoardWidget::findMove( POSITION& posA, POSITION& posB )
iPosCount = 0; // Hier Anzahl der gefunden Paare merken
// The new tile layout with non-contiguos horizantle spans
// can lead to huge numbers of matching pairs being exposed.
// we alter the loop to bail out when BoardLayout::maxTiles/2 pairs are found
// (or less);
@@ -1804,7 +1804,7 @@ bool BoardWidget::loadBackground(
if( ! theBackground.load( pszFileName, requiredWidth(), requiredHeight()) )
{
if( bShowError )
- KMessageBox::sorry(this, i18n("Failed to load image:\n%1").arg(pszFileName) );
+ KMessageBox::sorry(this, i18n("Failed to load image:\n%1").tqarg(pszFileName) );
return( false );
}
Prefs::setBackground(pszFileName);
@@ -2010,7 +2010,7 @@ void BoardWidget::shuffle() {
// force a redraw
updateBackBuffer=true;
- repaint(false);
+ tqrepaint(false);
// I consider this s very bad cheat so, I punish the user
@@ -766,7 +766,7 @@ void BoardWidget::calculateNewGame( int gNumber)
}
// ---------------------------------------------------------
-// Generate the position data for the layout from contents of Game.Map.
+// Generate the position data for the tqlayout from contents of Game.Map.
void BoardWidget::generateTilePositions() {
numTiles = 0;
@@ -788,7 +788,7 @@ void BoardWidget::generateTilePositions() {
}
// ---------------------------------------------------------
-// Generate the dependency data for the layout from the position data.
+// Generate the dependency data for the tqlayout from the position data.
// Note that the coordinates of each tile in tilePositions are those of
// the upper left quarter of the tile.
@@ -1393,7 +1393,7 @@ bool BoardWidget::findMove( POSITION& posA, POSITION& posB )
iPosCount = 0; // Hier Anzahl der gefunden Paare merken
- // The new tile layout with non-contiguos horizantle spans
+ // The new tile tqlayout with non-contiguos horizantle spans
// can lead to huge numbers of matching pairs being exposed.
// we alter the loop to bail out when BoardLayout::maxTiles/2 pairs are found